package com.cirs.biz.service;

import java.util.List;
import com.cirs.biz.domain.TElecCompRecord;
import com.cirs.biz.domain.UseInfofromRecord;

/**
 * 元器件使用经历Service接口
 * 
 * @author allen
 * @date 2023-11-04
 */
public interface ITElecCompRecordService 
{
    /**
     * 查询元器件使用经历
     * 
     * @param id 元器件使用经历主键
     * @return 元器件使用经历
     */
    public TElecCompRecord selectTElecCompRecordById(Long id);

    /**
     * 查询元器件使用经历列表
     * 
     * @param tElecCompRecord 元器件使用经历
     * @return 元器件使用经历集合
     */
    public List<TElecCompRecord> selectTElecCompRecordList(TElecCompRecord tElecCompRecord);

    /**
     * 新增元器件使用经历
     * 
     * @param tElecCompRecord 元器件使用经历
     * @return 结果
     */
    public int insertTElecCompRecord(TElecCompRecord tElecCompRecord);

    /**
     * 修改元器件使用经历
     * 
     * @param tElecCompRecord 元器件使用经历
     * @return 结果
     */
    public int updateTElecCompRecord(TElecCompRecord tElecCompRecord);

    /**
     * 批量删除元器件使用经历
     * 
     * @param ids 需要删除的元器件使用经历主键集合
     * @return 结果
     */
    public int deleteTElecCompRecordByIds(Long[] ids);

    /**
     * 删除元器件使用经历信息
     * 
     * @param id 元器件使用经历主键
     * @return 结果
     */
    public int deleteTElecCompRecordById(Long id);

    public List<UseInfofromRecord> getBycomponentId(Long componentId);

    public String importRecord(List<TElecCompRecord> recordList, boolean updateSupport, String operName);
}
